@@ -11,7 +11,7 @@ Puppet::Face.define(:file, '0.0.1') do
     EOT
 
     when_invoked do |path, options|
-      file = Puppet::FileBucket::File.new(File.read(path))
+      file = Puppet::FileBucket::File.new(IO.binread(path))
 
       Puppet::FileBucket::File.indirection.terminus_class = :file
       Puppet::FileBucket::File.indirection.save file
