@@ -35,12 +35,12 @@ class Puppet::FileServing::Content < Puppet::FileServing::Base
       # This stat can raise an exception, too.
       raise(ArgumentError, "Cannot read the contents of links unless following links") if stat.ftype == "symlink"
 
-      @content = ::File.read(full_path)
+      @content = IO.binread(full_path)
     end
     @content
   end
 
   def to_raw
-    File.new(full_path, "r")
+    File.new(full_path, "rb")
   end
 end
