@@ -26,7 +26,7 @@ class Puppet::Transaction::Report::Processor < Puppet::Indirector::Code
   # LAK:NOTE This isn't necessarily the best design, but it's backward
   # compatible and that's good enough for now.
   def process(report)
-    Puppet.debug "Recieved report to process from #{report.host}"
+    Puppet.debug "Received report to process from #{report.host}"
     processors do |mod|
       Puppet.debug "Processing report from #{report.host} with processor #{mod}"
       # We have to use a dup because we're including a module in the
