@@ -1,11 +1,10 @@
 require 'puppet/util/adsi'
 
 Puppet::Type.type(:group).provide :windows_adsi do
-  desc "Group management for Windows"
+  desc "Local group management for Windows. Nested groups are not supported."
 
   defaultfor :operatingsystem => :windows
-  confine :operatingsystem => :windows
-  confine :feature => :microsoft_windows
+  confine    :operatingsystem => :windows
 
   has_features :manages_members
 
@@ -23,6 +22,8 @@ Puppet::Type.type(:group).provide :windows_adsi do
 
   def create
     @group = Puppet::Util::ADSI::Group.create(@resource[:name])
+    @group.commit
+
     self.members = @resource[:members]
   end
 
@@ -34,12 +35,17 @@ Puppet::Type.type(:group).provide :windows_adsi do
     Puppet::Util::ADSI::Group.delete(@resource[:name])
   end
 
+  # Only flush if we created or modified a group, not deleted
+  def flush
+    @group.commit if @group
+  end
+
   def gid
-    nil
+    Puppet::Util::ADSI.sid_for_account(@resource[:name])
   end
 
   def gid=(value)
-    warning "No support for managing property gid of group #{@resource[:name]} on Windows"
+    fail "gid is read-only"
   end
 
   def self.instances
