@@ -15,27 +15,32 @@ module Puppet
 
     attr_reader :actual_content
 
-    desc "Specify the contents of a file as a string.  Newlines, tabs, and
-      spaces can be specified using standard escaped syntax in
-      double-quoted strings (e.g., \\n for a newline).
+    desc <<-EOT
+      The desired contents of a file, as a string. This attribute is mutually
+      exclusive with `source` and `target`.
 
-      With very small files, you can construct strings directly...
+      Newlines and tabs can be specified in double-quoted strings using
+      standard escaped syntax --- \n for a newline, and \t for a tab.
+
+      With very small files, you can construct content strings directly in
+      the manifest...
 
           define resolve(nameserver1, nameserver2, domain, search) {
-              $str = \"search $search
+              $str = "search $search
                   domain $domain
                   nameserver $nameserver1
                   nameserver $nameserver2
-                  \"
+                  "
 
-              file { \"/etc/resolv.conf\":
-                content => $str
+              file { "/etc/resolv.conf":
+                content => "$str",
               }
           }
 
       ...but for larger files, this attribute is more useful when combined with the
       [template](http://docs.puppetlabs.com/references/latest/function.html#template)
-      function."
+      function.
+    EOT
 
     # Store a checksum as the value, rather than the actual content.
     # Simplifies everything.
@@ -104,7 +109,7 @@ module Puppet
 
       if ! result and Puppet[:show_diff]
         write_temporarily do |path|
-          print diff(@resource[:path], path)
+          notice "\n" + diff(@resource[:path], path)
         end
       end
       result
@@ -192,7 +197,7 @@ module Puppet
     end
 
     def chunk_file_from_disk(source_or_content)
-      File.open(source_or_content.full_path, "r") do |src|
+      File.open(source_or_content.full_path, "rb") do |src|
         while chunk = src.read(8192)
           yield chunk
         end
