@@ -1,7 +1,6 @@
 require 'puppet'
 require 'sync'
 require 'getoptlong'
-require 'puppet/external/event-loop'
 require 'puppet/util/loadedfile'
 
 # The class for handling configuration files.
@@ -296,10 +295,6 @@ class Puppet::Util::Settings
     @sync.synchronize do
       unsafe_parse(self[:config])
     end
-
-    # Create a timer so that this file will get checked automatically
-    # and reparsed if necessary.
-    set_filetimeout_timer
   end
 
   # Unsafely parse the file -- this isn't thread-safe and causes plenty of problems if used directly.
@@ -492,6 +487,11 @@ class Puppet::Util::Settings
     end
     type = legacy_to_mode(type, param)
     @sync.synchronize do # yay, thread-safe
+      # Allow later inspection to determine if the setting was set on the
+      # command line, or through some other code path.  Used for the
+      # `dns_alt_names` option during cert generate. --daniel 2011-10-18
+      setting.setbycli = true if type == :cli
+
       @values[type][param] = value
       @cache.clear
 
@@ -544,12 +544,6 @@ class Puppet::Util::Settings
     call.each { |setting| setting.handle(self.value(setting.name)) }
   end
 
-  # Create a timer to check whether the file should be reparsed.
-  def set_filetimeout_timer
-    return unless timeout = self[:filetimeout] and timeout = Integer(timeout) and timeout > 0
-    timer = EventLoop::Timer.new(:interval => timeout, :tolerance => 1, :start? => true) { self.reparse }
-  end
-
   # Convert the settings we manage into a catalog full of resources that model those settings.
   def to_catalog(*sections)
     sections = nil if sections.empty?
@@ -927,4 +921,6 @@ if @config.include?(:run_mode)
       end
     end
   end
+
+
 end
